$ codeset=ISO-8859-1

$set 1 #Align

1 Bunden i midten
2 Bunden til venstre
3 Bunden til hjre
4 Horisontal
5 Til venstre
6 Til venstre i bunden
7 Til venstre i midten
8 Til venstre i toppen
9 Relativ
10 Til hjre
11 Til hjre i bunden
12 Til hjre i midten
13 Til hjre i toppen
14 Toppen i midten
15 verste venstre hjrne
16 verste hjre hjrne
17 Vertikal

$set 2 #BaseDisplay

1 Afslutter brat... laver et core dump\n
2 Lukker ned\n
3 %s:      signal %d fanget\n

$set 3 #Common

1 Alfa
2 Skjul automatisk
10 menu
11 stil
12 Standarder
13 Slet fra
14 Fejl
15 Fluxbox version
16 Maksimer over
17 GIT Revision
18 Synlig

$set 4 #Configmenu

1 Antialias
2 Hv automatisk
3 Klik hver
4 Klik for fokus
5 Dekorr transiente vinduer
6 Skift skrivebord med scroll-hjulet
7 Fokuser p vindue ved skrivebordsskift
8 Fokusmodel
9 Fokuser p nye vinduer
10 Fuld maksimering
11 Billede-dithering
12 Ugennemsigtig flytning af vinduer
13 Semislset Focus
14 Dovent fokus
15 Workspace Warping
16 Forcr pseudogennemsigtighed
18 Gennemsigtighed

$set 5 #Ewmh

1 Fatal fejl: Lbet tr for hukommelse, ikke nok til at allokere EWMH's klientliste.

$set 6 #FbTkError

1 Advarsel! Hjde > 3200, stter hjde = 3200
2 Advarsel! Bredde > 3200, stter bredde = 3200
3 Advarsel: Kan ikke indlse reserveskrifttype
4 Allokeringsfejl.
5 Fejl i oprettelse af pixmap
6 Kunne ikke oprette XImage (`Xbillede')
7 Kunne ikke lse.
8 Advarsel: Fandt ikke noget gyldigt format for alfa.
9 Advarsel: Kunne ikke oprette alfa-billede.
10 Advarsel: Kunne ikke oprette alfa-pixmap.
11 Kunne ikke finde format for skrm(%d)
12 Lbet tr for hukommelse
13 Lbet tr for hukommelse under allokering af bl buffer.
14 Lbet tr for hukommelse under allokering af grn buffer.
15 Lbet tr for hukommelse under allokering af rd buffer.
16 Kunne ikke lse tema-object
17 Uunderstttet visual
18 Stter standardvrdi

$set 7 #Fluxbox

1 rc-filnavn ugyldigt!
2 Kunne ikke indlse gruppefilen
3 Kunne ikke indlse databasen
4 Prver igen med
6 Kan ikke oprette mappen %s
7 Kunne ikke finde skrme til hndtering.\nSrg for at ikke at ha' en anden window manager krende.
8 Fejl: kan ikke parse regulrt udtryk
9 Fatal fejl: der kan kun vre en instans af klassen fluxbox.
10 Kunne ikke forbinde til X-serveren.\nSrg for at starte X fr du starter Fluxbox.
11 Advarsel: X-serveren understtter ikke lokale indstillinger (locale)
12 Advarsel: Kan ikke stte `locale'-modifikatorer

$set 8 #Gnome

1 Fatal fejl: Lbet tr for hukommelse, ikke nok til at allokere GNOME's klientliste.

$set 9 #Keys

1 Taster (Keys): Fejl p linie
2 Taster (Keys): kunne ikke sammenflette tastetr!
3 Taster (Keys): Ugyldig tast p linie

$set 10 #Menu

1 Indstillinger
2 Fluxbox standardmenu
3 Afslut
4 Ikoner
5 Lag...
7 Placering
8 Genindls indstillinger
9 Genstart

$set 11 #Remember

1 Dekorationer
2 Strrelse
3 G til skriverbord
4 Lag
5 Husk...
6 Placering
7 Gem ved lukning
8 Kun titelbjlke
9 P alle skriveborde
10 Ukendt apps ngle
11 Skrivebord

$set 12 #Screen

1 BScreen::BScreen: der opstod en fejl under foresprgsel til X server.\n	en anden window manager krer allerede p display
2 B: %4d x H: %4d
3 BScreen::BScreen: hndterer skrm %d med visual 0x%lx, dybde %d\n
4 B: %04d x H: %04d

$set 13 #Slit

1 Klienter
4 Slidsretning
5 Slidslag
7 Slidsplacering
8 Slids
9 Gem slidsliste

$set 14 #Toolbar

1 Rediger skrivebordets navn
2 Vinduer vist i vjktjsbjlken
3 Alle
4 Minimerede
5 Ingen
6 P skrivebord
7 Minimerede p skrivebord
8 Vrktjsbjlkelag
10 Vrktjsbjlkens placering
11 Vrktjsbjlke
13 Ur: 24 timer
14 Ur: 12 timer
15 Rediger tidsformat
16 Vis billeder
17 Ikke-minimerede
18 Ikke-minimerede p skrivebord

$set 15 #Window

1 Intet navn

$set 16 #Windowmenu

1 Luk
2 Minimeret
3 Lag
4 Snk
5 Maksimer
6 Hv
7 Send til ...
8 Kun titelbjlke
9 P alle skriveborde
10 Luk abrupt

$set 17 #Workspace

1 Skrivebord %d
2 Skriveborde
3 Nyt skrivebord
4 Fjern sidste

$set 18 #fbsetroot

1 fejl: specificr en af flgende: -solid, -mod, -gradient\n
3 -display <string>        skrmtilslutning\n\
-mod <x> <y>             modula mnster\n\
-foreground, -fg <color> modula foregrundsfarve\n\
-background, -bg <color> modula baggrundsfarve\n\n\
-gradient <texture>      gradienttekstur\n\
-from <color>            gradientens startfarve\n\
-to <color>              gradientens slutfarve\n\n\
-solid <color>           fast farve\n\n\
-help                    vis denne hjlp og afslut\n

$set 19 #main

1 fejl: '-display' krver et argument
2 Drlig allokering
7 Ukendt fejl
9 Logfil
10 Logger til
11 fejl: '-rc' krver et argument
13 Fluxbox %s: (c) %s Henrik Kinnunen\n\n\
-display <string>\t\tbrug skrmtilslutning.\n\
-rc <string>\t\t\tbrug alternativ resourcefil.\n\
-version\t\t\tvis versionsnummer og afslut.\n\
-info\t\t\t\tvis noget nyttig information.\n\
-log <filename>\t\t\tlog output til fil.\n\
-help\t\t\t\tvis denne hjlp og afslut.\n\n

$set 20 #layers

1 Over dok
2 Nederst
3 Skrivebord
4 Dok
5 Normal
6 verst
